@@ -351,19 +351,19 @@ class ISCSIInitiatorUtilsTestCase(test_base.OsWinBaseTestCase):
                        '_get_iscsi_sessions')
     def test_get_iscsi_target_sessions(self, mock_get_iscsi_sessions,
                                         target_sessions_found=True):
-        fake_session = mock.Mock(TargetNodeName="FAKE_TARGET_NAME",
+        fake_session = mock.Mock(TargetNodeName=mock.sentinel.target_name,
                                  ConnectionCount=1)
         fake_disconn_session = mock.Mock(
-            TargetNodeName="fake_target_name",
+            TargetNodeName=mock.sentinel.target_name,
             ConnectionCount=0)
-        other_session = mock.Mock(TargetNodeName="other_target_name",
+        other_session = mock.Mock(TargetNodeName=mock.sentinel.other_target,
                                   ConnectionCount=1)
 
         sessions = [fake_session, fake_disconn_session, other_session]
         mock_get_iscsi_sessions.return_value = sessions
 
         resulted_tgt_sessions = self._initiator._get_iscsi_target_sessions(
-            "fake_target_name")
+            mock.sentinel.target_name)
 
         self.assertEqual([fake_session], resulted_tgt_sessions)
 
@@ -670,7 +670,8 @@ class ISCSIInitiatorUtilsTestCase(test_base.OsWinBaseTestCase):
             auth_username=mock.sentinel.auth_username,
             auth_password=mock.sentinel.auth_password,
             auth_type=mock.sentinel.auth_type,
-            mpio_enabled=mpio_enabled)
+            mpio_enabled=mpio_enabled,
+            rescan_attempts=mock.sentinel.rescan_attempts)
 
         mock_get_targets.assert_called_once_with()
         mock_add_static_target.assert_called_once_with(
@@ -702,7 +703,8 @@ class ISCSIInitiatorUtilsTestCase(test_base.OsWinBaseTestCase):
 
         mock_ensure_lun_available.assert_called_once_with(
             mock.sentinel.target_iqn,
-            mock.sentinel.target_lun)
+            mock.sentinel.target_lun,
+            mock.sentinel.rescan_attempts)
 
     def test_login_storage_target_path_exists(self):
         self._test_login_storage_target(login_required=False)
