@@ -292,7 +292,6 @@ class VHDUtilsTestCase(base.BaseTestCase):
         mock_open.return_value = mock.sentinel.handle
         mock_get_vhd_info_member.return_value = fake_vhd_info
 
-        expected_open_flag = vdisk_const.OPEN_VIRTUAL_DISK_FLAG_NO_PARENTS
         expected_access_mask = (vdisk_const.VIRTUAL_DISK_ACCESS_GET_INFO |
                                 vdisk_const.VIRTUAL_DISK_ACCESS_DETACH)
 
@@ -302,7 +301,6 @@ class VHDUtilsTestCase(base.BaseTestCase):
         self.assertEqual(fake_vhd_info, ret_val)
         mock_open.assert_called_once_with(
             mock.sentinel.vhd_path,
-            open_flag=expected_open_flag,
             open_access_mask=expected_access_mask)
         self._vhdutils._get_vhd_info_member.assert_called_once_with(
             mock.sentinel.handle,
