@@ -46,8 +46,12 @@ utils_map = {
     'hostutils': {
         'HostUtils': {
             'min_version': 6.2,
+            'max_version': 10,
+            'path': 'os_win.utils.hostutils.HostUtils'},
+        'HostUtils10': {
+            'min_version': 10,
             'max_version': None,
-            'path': 'os_win.utils.hostutils.HostUtils'}},
+            'path': 'os_win.utils.hostutils10.HostUtils10'}},
     'iscsi_initiator_utils': {
         'ISCSIInitiatorCLIUtils': {
             'min_version': 6.0,
@@ -133,7 +137,7 @@ utils_map = {
 }
 
 
-def _get_class(class_type, *args, **kwargs):
+def _get_class(class_type):
     if class_type not in utils_map:
         raise exceptions.HyperVException(_('Class type %s does '
                                            'not exist') % class_type)
@@ -148,8 +152,7 @@ def _get_class(class_type, *args, **kwargs):
         if (utils_class['min_version'] <= windows_version and
                 (utils_class['max_version'] is None or
                  windows_version < utils_class['max_version'])):
-            return importutils.import_object(utils_class['path'],
-                                             *args, **kwargs)
+            return importutils.import_object(utils_class['path'])
 
     raise exceptions.HyperVException(_('Could not find any %(class)s class for'
         'this Windows version: %(win_version)s')
@@ -157,7 +160,7 @@ def _get_class(class_type, *args, **kwargs):
 
 
 def get_vmutils(host='.'):
-    return _get_class(class_type='vmutils', host=host)
+    return _get_class(class_type='vmutils')
 
 
 def get_vhdutils():
